( cd usr/lib ; rm -rf libvisual-0.4.so.0 )
( cd usr/lib ; ln -sf libvisual-0.4.so.0.0.0 libvisual-0.4.so.0 )
( cd usr/lib ; rm -rf libvisual-0.4.so )
( cd usr/lib ; ln -sf libvisual-0.4.so.0.0.0 libvisual-0.4.so )
